@@ -1,8 +1,6 @@
 module Lens.Family.State.Zoom where
 
-import Control.Applicative (Applicative, pure, (<*>))
 import Control.Monad (liftM)
-import Data.Monoid (Monoid, mempty, mappend)
 
 newtype Zooming m c a = Zooming { unZooming :: m (c, a) }
 
@@ -14,4 +12,4 @@ instance (Monoid c, Monad m) => Applicative (Zooming m c) where
   Zooming f <*> Zooming x = Zooming $ do
     (a, f') <- f
     (b, x') <- x
-    return (a `mappend` b, f' x')
+    return (a <> b, f' x')
